@@ -92,6 +92,8 @@ def post_status(
     spoiler_text=None,
     in_reply_to_id=None,
     language=None,
+    scheduled_at=None,
+    content_type=None,
 ):
     """
     Posts a new status.
@@ -102,7 +104,7 @@ def post_status(
     # if the request is retried.
     headers = {"Idempotency-Key": uuid.uuid4().hex}
 
-    return http.post(app, user, '/api/v1/statuses', {
+    params = {
         'status': status,
         'media_ids[]': media_ids,
         'visibility': visibility,
@@ -110,7 +112,13 @@ def post_status(
         'spoiler_text': spoiler_text,
         'in_reply_to_id': in_reply_to_id,
         'language': language,
-    }, headers=headers).json()
+        'scheduled_at': scheduled_at
+    }
+
+    if content_type:
+        params['content_type'] = content_type
+
+    return http.post(app, user, '/api/v1/statuses', params, headers=headers).json()
 
 
 def delete_status(app, user, status_id):
@@ -215,10 +223,11 @@ def anon_tag_timeline_generator(instance, hashtag, local=False, limit=20):
     return _anon_timeline_generator(instance, path, params)
 
 
-def upload_media(app, user, file):
-    return http.post(app, user, '/api/v1/media', files={
-        'file': file
-    }).json()
+def upload_media(app, user, file, description=None):
+    return http.post(app, user, '/api/v1/media',
+        data={'description': description},
+        files={'file': file}
+    ).json()
 
 
 def search(app, user, query, resolve):
@@ -268,8 +277,9 @@ def single_status(app, user, status_id):
     return http.get(app, user, url).json()
 
 
-def get_notifications(app, user):
-    return http.get(app, user, '/api/v1/notifications').json()
+def get_notifications(app, user, exclude_types=[], limit=20):
+    params={"exclude_types[]": exclude_types, "limit": limit}
+    return http.get(app, user, '/api/v1/notifications', params).json()
 
 
 def clear_notifications(app, user):
